@@ -7,15 +7,17 @@
 
 """Factory pattern for archives that are maintained on disk."""
 
+from typing import Callable, Dict, Optional, Union
+
 import json
 import os
 import shutil
 
-from typing import Dict, List, Optional, Union
-
-from histore.archive.base import PersistentArchive
+from histore.archive.base import Archive, InputDocument, PersistentArchive, PrimaryKey
 from histore.archive.manager.base import ArchiveManager
 from histore.archive.manager.descriptor import ArchiveDescriptor
+from histore.archive.store.fs.base import ArchiveFileStore
+from histore.document.base import InputDescriptor
 
 import histore.config as config
 import histore.util as util
@@ -62,6 +64,20 @@ class FileSystemArchiveManager(ArchiveManager):
                 descriptor = ArchiveDescriptor(obj)
                 self._archives[descriptor.identifier()] = descriptor
 
+    def _archive_dir(self, identifier: str) -> str:
+        """Get directory for archive with the given identifier.
+
+        Parameters
+        ----------
+        identifier: string
+            Unique archive identifier.
+
+        Returns
+        -------
+        string
+        """
+        return os.path.join(self.basedir, identifier)
+
     def archives(self) -> Dict[str, ArchiveDescriptor]:
         """Get dictionary of archive descriptors. The returned dictionary maps
         archive identifier to their descriptor.
@@ -74,11 +90,19 @@ class FileSystemArchiveManager(ArchiveManager):
 
     def create(
         self, name: Optional[str] = None, description: Optional[str] = None,
-        primary_key: Optional[Union[List[str], str]] = None,
-        encoder: Optional[str] = None, decoder: Optional[str] = None
+        encoder: Optional[str] = None, decoder: Optional[str] = None,
+        serializer: Union[Dict, Callable] = None, doc: Optional[InputDocument] = None,
+        primary_key: Optional[PrimaryKey] = None, snapshot: Optional[InputDescriptor] = None,
+        sorted: Optional[bool] = False, buffersize: Optional[float] = None,
+        validate: Optional[bool] = False
     ) -> ArchiveDescriptor:
-        """Create a new archive object. Raises a ValueError if an archive with
-        the given name exists.
+        """Create a new archive object under a given unique name.
+
+        For archives that are keyed by a primary key, the input document for
+        the first dataset snapshot has to be provided. This snapshot will be
+        loaded into the archive.
+
+        Raises a ValueError if an archive with the given name exists.
 
         Parameters
         ----------
@@ -86,14 +110,37 @@ class FileSystemArchiveManager(ArchiveManager):
             Descriptive name that is associated with the archive.
         description: string, default=None
             Optional long description that is associated with the archive.
-        primary_key: string or list, default=None
-            Column(s) that are used to generate identifier for rows in the
-            archive.
         encoder: string, default=None
             Full package path for the Json encoder class that is used by the
             persistent archive.
         decoder: string, default=None
             Full package path for the Json decoder function that is used by the
+            persistent archive.
+        serializer: dict or callable, default=None
+            Dictionary or callable that returns a dictionary that contains the
+            specification for the serializer. The serializer specification is
+            a dictionary with the following elements:
+            - ``clspath``: Full package target path for the serializer class
+            that is instantiated.
+            - ``kwargs`` : Additional arguments that are passed to the
+            constructor of the created serializer instance.
+            Only ``clspath`` is required.
+        doc: histore.archive.base.InputDocument, default=None
+            Input document representing the initial dataset snapshot that is
+            being loaded into the archive.
+        primary_key: string or list, default=None
+            Column(s) that are used to generate identifier for snapshot rows.
+        snapshot: histore.document.base.InputDescriptor, default=None
+            Optional metadata for the created snapshot.
+        sorted: bool, default=False
+            Flag indicating if the document is sorted by the optional primary
+            key attributes. Ignored if the archive is not keyed.
+        buffersize: float, default=None
+            Maximum size (in bytes) for the memory buffer when sorting the
+            input document.
+        validate: bool, default=False
+            Validate that the resulting archive is in proper order before
+            committing the action.
 
         Returns
         -------
@@ -106,16 +153,33 @@ class FileSystemArchiveManager(ArchiveManager):
         # Ensure that the archive name is unique.
         if self.get_by_name(name) is not None:
             raise ValueError("archive '{}' already exists".format(name))
+        # Create an unique identifier for the new archive.
+        identifier = util.get_unique_identifier()
+        # Create persistent archive. This will load the initial snapshot if a
+        # document is given.
+        archive = PersistentArchive(
+            basedir=self._archive_dir(identifier),
+            create=True,
+            serializer=serializer,
+            encoder=encoder,
+            decoder=decoder,
+            descriptor=snapshot,
+            doc=doc,
+            primary_key=primary_key,
+            sorted=sorted,
+            buffersize=buffersize,
+            validate=validate
+        )
         # Create the descriptor for the new archive.
         descriptor = ArchiveDescriptor.create(
+            identifier=identifier,
             name=name,
             description=description,
-            primary_key=primary_key,
+            primary_key=archive.store.primary_key(),
             encoder=encoder,
-            decoder=decoder
+            decoder=decoder,
+            serializer=serializer
         )
-        identifier = descriptor.identifier()
-        primary_key = descriptor.primary_key()
         # Write list of archive descriptors.
         self._archives[identifier] = descriptor
         self.write()
@@ -130,13 +194,12 @@ class FileSystemArchiveManager(ArchiveManager):
             Unique archive identifier
         """
         if self.contains(identifier):
-            archdir = os.path.join(self.basedir, identifier)
-            if os.path.isdir(archdir):
-                shutil.rmtree(archdir)
+            archdir = self._archive_dir(identifier)
+            shutil.rmtree(archdir)
             del self._archives[identifier]
             self.write()
 
-    def get(self, identifier: str) -> PersistentArchive:
+    def get(self, identifier: str) -> Archive:
         """Get the archive that is associated with the given identifier. Raises
         a ValueError if the identifier is unknown.
 
@@ -156,25 +219,15 @@ class FileSystemArchiveManager(ArchiveManager):
         desc = self._archives.get(identifier)
         if desc is None:
             raise ValueError('unknown archive {}'.format(identifier))
-        archdir = os.path.join(self.basedir, identifier)
-        primary_key = desc.primary_key()
-        # Load JSONEncoder class if encoder is contained in the descriptor.
-        if desc.encoder() is not None:
-            encoder = util.import_obj(desc.encoder())
-        else:
-            encoder = None
-        # Load the corresponding Json decoder function if a decoder is
-        # contained in the descriptor.
-        if desc.decoder() is not None:
-            decoder = util.import_obj(desc.decoder())
-        else:
-            decoder = None
-        return PersistentArchive(
-            basedir=archdir,
-            primary_key=primary_key,
-            encoder=encoder,
-            decoder=decoder
+        store = ArchiveFileStore(
+            basedir=self._archive_dir(identifier),
+            replace=False,
+            serializer=desc.serializer(),
+            encoder=desc.encoder(),
+            decoder=desc.decoder(),
+            primary_key=desc.primary_key()
         )
+        return Archive(store=store)
 
     def rename(self, identifier: str, name: str):
         """Rename the specified archive. Raises a ValueError if the identifier
