@@ -10,10 +10,7 @@ dataset archive.
 """
 
 
-def merge_rows(
-    arch_reader, doc_reader, version, writer, partial=False,
-    unchanged_cells=None, origin=None
-):
+def merge_rows(arch_reader, doc_reader, version, writer):
     """Merge rows in the given archive and database snapshot. Outputs the
     merged rows in the resulting archive to the given archive writer.
 
@@ -27,17 +24,6 @@ def merge_rows(
         Identifier of the new archive version.
     writer: histore.archive.writer.ArchiveWriter
         Consumer for rows in the new archive version.
-    partial: bool, default=False
-        Flag indicating whether the given document is a partial document. For
-        partial documents missing rows in the archive are considered unchanged
-        with respect to the given origin.
-    unchanged_cells: set, default=None
-        Set of identifier for columns whose cell values are not included in
-        the values dictionary for document rows but that remain unchanged with
-        respect to the specified source version (origin).
-    origin: int, default=None
-        Version that the row values originate from. Rows that remain unchanged
-        have the timestamp extended for the version of origin.
     """
     # Get the first row for each reader.
     arch_row = arch_reader.next()
@@ -45,13 +31,8 @@ def merge_rows(
     while arch_row is not None and doc_row is not None:
         comp = arch_row.comp(doc_row.key)
         if comp < 0:
-            # The row is not present in the document. If the document is
-            # a partial document we need to extend the row for the given
-            # origin.
-            if partial:
-                arch_row = arch_row.extend(version=version, origin=origin)
-            # Add the row to the new archive version and progress the
-            # archive reader.
+            # The row is not present in the document. Include the row without
+            # changes to the new archive version and read the next archive row.
             writer.write_archive_row(arch_row)
             arch_row = arch_reader.next()
         elif comp > 0:
@@ -65,9 +46,7 @@ def merge_rows(
             arch_row = arch_row.merge(
                 values=doc_row.values,
                 pos=doc_row.pos,
-                version=version,
-                unchanged_cells=unchanged_cells,
-                origin=origin
+                version=version
             )
             # Add the merged row to the new archive version and progress
             # both readers.
@@ -79,9 +58,6 @@ def merge_rows(
     # document rows.
     # Add remaining archive rows to the new archive version.
     while arch_row is not None:
-        # Extend the row for the given origin if the document is partial.
-        if partial:
-            arch_row = arch_row.extend(version=version, origin=origin)
         writer.write_archive_row(arch_row)
         arch_row = arch_reader.next()
     # Add remaining document rows to the new archive version.
@@ -89,3 +65,4 @@ def merge_rows(
         # Output an archive row created from the document row.
         writer.write_document_row(row=doc_row, version=version)
         doc_row = doc_reader.next()
+    doc_reader.close()
