@@ -11,13 +11,13 @@ history.
 """
 
 from __future__ import annotations
-from typing import Dict, List, Optional, Set, Tuple, Union
+from typing import Dict, List, Optional, Tuple, Union
 
-from histore.key.base import KeyValue
+from histore.key import KeyValue
 from histore.archive.provenance.base import ProvOp
 from histore.archive.provenance.row import DeleteRow, InsertRow, UpdateRow
 from histore.archive.value import ArchiveValue, SingleVersionValue
-from histore.archive.timestamp import Timestamp
+from histore.archive.timestamp import SingleVersion, Timestamp
 
 
 class ArchiveRow(object):
@@ -36,7 +36,7 @@ class ArchiveRow(object):
         ----------
         rowid: int
             Unique internal row identifier
-        key: histore.key.base.KeyValue, or tuple
+        key: histore.key.KeyValue, or tuple
             Derived row key for matching and merging purposes.
         pos: histore.archive.value.ArchiveValue
             Index positions for the row in the history of the dataset.
@@ -82,7 +82,7 @@ class ArchiveRow(object):
 
     def at_version(
         self, version: int, columns: List[int], raise_error: Optional[bool] = True
-    ):
+    ) -> Tuple[int, List]:
         """Get cell values and the index position for the row in the given
         version of the dataset. Returns the index position of the row and a
         list of cell values for all columns in the given list. The order of
@@ -101,7 +101,7 @@ class ArchiveRow(object):
 
         Returns
         -------
-        int, dict
+        int, list
         """
         values = list()
         for colid in columns:
@@ -128,7 +128,7 @@ class ArchiveRow(object):
 
         Parameters
         ----------
-        key: histore.key.base.KeyValue, or tuple
+        key: histore.key.KeyValue, or tuple
             Key value of a document row.
 
         Returns
@@ -228,22 +228,13 @@ class ArchiveRow(object):
             timestamp=self.timestamp.append(version)
         )
 
-    def merge(
-        self, values: Dict, pos: int, version: int,
-        unchanged_cells: Optional[Set] = None, origin: Optional[int] = None
-    ) -> ArchiveRow:
+    def merge(self, values: Dict, pos: int, version: int,) -> ArchiveRow:
         """Create a new version of the dataset row for a given set of cell
-        values and a specified index position. The set of extend cells
-        identifies those columns that are not present in the value dictionary
-        but that remain valid in the new version with respect to the given
-        source version (origin).
+        values and a specified index position.
 
         Values is a dictionary that maps column identifier to cell values in
-        the new row. Columns that are not present in the dictionary the have
-        either be deleted or remain unchanged. In the latter case, these
-        columns are included in the set of unchanged columns. Columns that
-        are unchanged are keep the value that they had in the given source
-        version (origin).
+        the new row. Columns that are not present in the dictionary have been
+        deleted.
 
         Parameters
         ----------
@@ -254,14 +245,6 @@ class ArchiveRow(object):
             Index position of the row in the dataset snapshot.
         version: int
             Identifier of the new row version.
-        unchanged_cells: set, default=None
-            Set of identifier for columns whose cell values are not included in
-            the values dictionary but that remain unchanged with respect to the
-            specified source version (origin).
-        origin: int, default=None
-            Version that the row values originate from. Cell that remain
-            unchanged have the timestamp extended for the version the was
-            present the version of origin.
 
         Returns
         -------
@@ -276,21 +259,13 @@ class ArchiveRow(object):
             else:
                 cell = SingleVersionValue(
                     value=value,
-                    timestamp=Timestamp(version=version)
+                    timestamp=SingleVersion(version=version)
                 )
             history[colid] = cell
-        # For missing columns either add them as they are (e.g., if the column
-        # has been deleted) or if they are included in the unchanged set append
-        # the new version to the timestamp for the value that was valid at the
-        # source version.
-        unchanged = unchanged_cells if unchanged_cells is not None else set()
+        # For missing columns add them as they are (e.g., if the column
+        # has been deleted).
         for colid, cell in self.cells.items():
             if colid not in history:
-                if colid in unchanged:
-                    cell = cell.extend(
-                        version=version,
-                        origin=origin
-                    )
                 history[colid] = cell
         # Return a modified archive row.
         return ArchiveRow(
